summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmlightedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmlightedit.h')
-rw-r--r--kpovmodeler/pmlightedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmlightedit.h b/kpovmodeler/pmlightedit.h
index 75b56530..d3a595c5 100644
--- a/kpovmodeler/pmlightedit.h
+++ b/kpovmodeler/pmlightedit.h
@@ -45,9 +45,9 @@ class PMLightEdit : public PMNamedObjectEdit
typedef PMNamedObjectEdit Base;
public:
/**
* Creates a PMLightEdit with tqparent and name
*/
- PMLightEdit( TQWidget* tqparent, const char* name = 0 );
+ PMLightEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -45,9 +45,9 @@ class PMLightEdit : public PMNamedObjectEdit
public:
/**
- * Creates a PMLightEdit with tqparent and name
+ * Creates a PMLightEdit with parent and name
*/